summaryrefslogtreecommitdiff
path: root/tests/date
diff options
context:
space:
mode:
authorJim Meyering <jim@meyering.net>2000-03-11 16:17:25 +0000
committerJim Meyering <jim@meyering.net>2000-03-11 16:17:25 +0000
commit9370e7d2a8d2af41ef36a29637750c65ab65d53e (patch)
treecba2643075bfcefacc65d3c02e5ef4dfe628da52 /tests/date
parent3b89449b19252312cba2ceec2db796c6f9d43a04 (diff)
downloadcoreutils-9370e7d2a8d2af41ef36a29637750c65ab65d53e.tar.xz
Set the default TZ value to UTC0, not UTC.
The latter didn't have any effect on alphaev56-dec-osf4.0f.
Diffstat (limited to 'tests/date')
-rw-r--r--tests/date/Test.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/date/Test.pm b/tests/date/Test.pm
index a910dcfc5..8d8375ace 100644
--- a/tests/date/Test.pm
+++ b/tests/date/Test.pm
@@ -5,8 +5,8 @@ use strict;
# For each test...
# Export LANG=C so that the locale-dependent strings match.
-# Export TZ=UTC so that zone-dependent strings match.
-$Test::env_default = ['LANG=C TZ=UTC'];
+# Export TZ=UTC0 so that zone-dependent strings match.
+$Test::env_default = ['LANG=C TZ=UTC0'];
sub test_vector
{